@@ -38,7 +38,7 @@ our @testbench = (
 ["center_layer"        , 2, REQ_ALPHA, [] ],
 ["contrast_enhance_2x2", 1, REQ_NONE , [] ],
 ["ditherize"           , 1, REQ_NONE , [1, 10] ],
-["do_bricks"           , 0, REQ_NONE , ["Leather","unused yet","",'grey50',1,8,16,256,256,0] ],
+["do_bricks"           , 0, REQ_NONE , ["Leather",0,"",'grey50',1,8,16,256,256,0] ],
 ["dots"                , 1, REQ_NONE , [8,$color1,80,20,16,0,0] ],
 ["dust"                , 1, REQ_NONE , [0.0005,0,50] ],
 ["edge_detect_2x2"     , 1, REQ_NONE , [] ],
@@ -50,10 +50,8 @@ our @testbench = (
 ["guide_to_selection"  , 1, REQ_GUIDE, [CHANNEL_OP_REPLACE,0,0] ],
 ["highlight_edges"     , 1, REQ_ALPHA, [ 10] ],
 ["inner_bevel"         , 0, REQ_NONE , ["URW Bookman L, Bold",80,"INNERBEVEL",$color1,$color2,132,30,7,2] ],
-["layer_apply"         , 1, REQ_NONE , ['$d->gauss_rle($P*100+1,1,1)',""] ],
+["layer_apply"         , 1, REQ_NONE , ['$d->gauss_rle($P*100+1,1,1)',0] ],
 ["layer_reorder"       , 3, REQ_ALPHA, [1,""] ],
-["make_bevel_logos"    , 1, REQ_ALPHA, [$white,$color1,$color2,45,4,0] ],
-["make_trans_logos"    , 1, REQ_ALPHA, [0,$gradient1,$color1] ],
 ["map_to_gradient"     , 1, REQ_NONE , [$gradient1] ],
 ["mirror_split"        , 1, REQ_NONE , [0] ],
 ["perlotine"           , 1, REQ_GUIDE|REQ_DIR, ["foo.html","t","png",0,"",1,0] ],
@@ -64,7 +62,6 @@ our @testbench = (
 ["random_blends"       , 1, REQ_NONE , [7] ],
 ["red_eye"             , 1, REQ_NONE , [0] ],
 ["repdup"              , 1, REQ_SEL  , [3,50,50] ],
-["round_sel"           , 1, REQ_SEL  , [16] ],
 ["scratches"           , 1, REQ_NONE , [30,70,0.3,15,10] ],
 ["selective_sharpen"   , 1, REQ_NONE , [5.0,1.0,20] ],
 ["seth_spin"           , 2, REQ_LAYER, [16,$color1,40,1,1] ],
